@@ -1403,13 +1403,8 @@ int modbus_set_slave(modbus_t *ctx, int slave)
 int modbus_set_error_recovery(modbus_t *ctx,
                               modbus_error_recovery_mode error_recovery)
 {
-    if (error_recovery >= 0) {
-        ctx->error_recovery = (uint8_t) error_recovery;
-    } else {
-        errno = EINVAL;
-        return -1;
-    }
-
+    /* The type of modbus_error_recovery_mode is unsigned enum */
+    ctx->error_recovery = (uint8_t) error_recovery;
     return 0;
 }
 
